@@ -7,16 +7,34 @@ from daemon import DaemonContext
 from datetime import datetime
 from lock import Lock
 from os import mkdir
-from os.path import getmtime, exists
+from os.path import getmtime, exists, dirname, join
+from shutil import copyfile
 
 from netifaces import interfaces, ifaddresses
 from ojota import set_data_source
+from pyaml import yaml
+from qtfaststart.processor import get_index
+from qtfaststart.exceptions import FastStartException
 
-from touchandgo.logger import log_set_up
+
+from touchandgo.settings import SKIP_MOOV
 
 
 LOCKFILE = "/tmp/touchandgo"
 
+log = logging.getLogger('touchandgo.helpers')
+
+def get_settings():
+    settings_file = "%s/.touchandgo/settings.yaml" % os.getenv("HOME")
+
+    if not exists(settings_file):
+        default = join(dirname(__file__), "templates", "settings.yaml")
+        copyfile(default, settings_file)
+
+    settings = yaml.load(open(settings_file).read())
+    return settings
+
+
 
 def get_free_port():
     socket_ = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -60,6 +78,7 @@ def is_process_running(process_id):
 
 def daemonize(args, callback):
     with DaemonContext():
+        from touchandgo.logger import log_set_up
         log_set_up(True)
         log = logging.getLogger('touchandgo.daemon')
         log.info("running daemon")
@@ -67,6 +86,7 @@ def daemonize(args, callback):
         lock = Lock(LOCKFILE, os.getpid(), args.name, args.sea_ep[0],
                     args.sea_ep[1], args.port)
         if lock.is_locked():
+            log.debug("lock active")
             lock_pid = lock.get_pid()
             if not lock.is_same_file(args.name, args.sea_ep[0],
                                      args.sea_ep[1]) \
@@ -86,9 +106,10 @@ def daemonize(args, callback):
         if create_process:
             log.debug("creating proccess")
             lock.acquire()
-            callback(args.name, season=args.sea_ep[0], episode=args.sea_ep[1],
-                     serve=True, port=args.port)
+            callback()
             lock.release()
+        else:
+            log.debug("same daemon process")
 
 
 def get_lock_diff():
@@ -109,3 +130,26 @@ def set_config_dir():
 
     set_data_source(data_folder)
 
+
+def have_moov(video_file):
+    if not SKIP_MOOV:
+        atoms = {}
+        log.info("Checking moov data of %s", video_file)
+        try:
+            atom_data = get_index(open(video_file, 'rb'))
+            for atom in atom_data:
+                atoms[atom.name] = atom.position
+            log.debug("moov:%(moov)s mdat:%(mdat)s ftyp:%(ftyp)s free:%(free)s",
+                    atoms)
+
+            if atoms['moov'] > atoms['mdat']:
+                log.info("moov atom after mdat")
+                return True, "after_mdat"
+            else:
+                log.info("moov atom before mdat")
+                return True
+        except FastStartException as e:
+            log.error("Couldn't get Atoms data: %s", str(e))
+            return False
+    else:
+        return True
